@@ -17,20 +17,29 @@ from ..ops import load_hash, Conflict
 
 
 class PullMode(Enum):
-    copy = 'copy'
+    """
+    How to restore the files:
+
+    hash - restore the file hash. Useful for basic files/folders manipulation, e.g. removing parts of a tree
+
+    copy - copy the files. Useful for making changes to files' contents
+    """
+
     hash = 'hash'
+    copy = 'copy'
 
 
 @app_command
 def pull(
         sources: List[Path] = typer.Argument(..., help='The source paths to add', show_default=False),
-        mode: PullMode = typer.Option(..., help='Pull mode', show_default=False),
+        mode: PullMode = typer.Option(..., help=PullMode.__doc__, show_default=False),
         destination: Optional[Path] = typer.Option(
             None, '--destination', '--dst',
-            help='The destination at which the hashes will be stored. '
-                 'If none -  the hashes will be stored alongside the source'
+            help='The destination at which the results will be stored. '
+                 'If none -  the results will be stored alongside the source'
         ),
         keep: bool = typer.Option(False, help='Whether to keep the sources after pulling the real files'),
+        fetch: bool = typer.Option(False, help='Whether to fetch the missing files from remote, if possible'),
         repository: Path = typer.Option(
             None, '--repository', '--repo', help='The bev repository. It is usually detected automatically',
             show_default=False,
@@ -73,11 +82,16 @@ def pull(
             # TODO: warn
             continue
 
-        _pull(source, destination, mode.name, keep, repo)
+        _pull(source, destination, mode, keep, repo, fetch)
 
 
-def _pull(source, destination, mode, keep, repo):
-    h = load_hash(source, repo.storage)
+def _pull(source, destination, mode, keep, repo, fetch):
+    def add_ext(p):
+        if mode is PullMode.hash and not is_hash(p):
+            p = to_hash(p)
+        return p
+
+    h = load_hash(source, repo.storage, fetch)
     if isinstance(h, dict):
         if destination.is_file():
             raise cli_error(
@@ -86,31 +100,36 @@ def _pull(source, destination, mode, keep, repo):
             )
 
         for file, value in track(h.items(), total=len(h)):
-            file = destination / file
+            file = add_ext(destination / file)
             file.parent.mkdir(parents=True, exist_ok=True)
-            PULL_MODES[mode](value, file, repo)
+            PULL_MODES[mode](value, file, repo, fetch)
 
     else:
+        destination = add_ext(destination)
         if destination.is_dir():
             raise cli_error(
                 OSError,
                 f'The destination ({destination}) is a folder, but the hash ({source}) contains a single file',
             )
 
-        PULL_MODES[mode](h, destination, repo)
+        if source == destination:
+            # TODO: warn
+            return
+
+        PULL_MODES[mode](h, destination, repo, fetch)
 
     if not keep:
         os.remove(source)
 
 
-def save_hash(value, file, repo):
-    with open(to_hash(file), 'w') as f:
+def save_hash(value, file, repo, fetch):
+    with open(file, 'w') as f:
         f.write(value)
 
 
 PULL_MODES = {
-    'copy': lambda h, dst, repo: repo.storage.read(shutil.copyfile, h, dst),
-    'hash': save_hash,
+    PullMode.copy: lambda h, dst, repo, fetch: repo.storage.read(shutil.copyfile, h, dst, fetch=fetch),
+    PullMode.hash: save_hash,
 }
 
 
