@@ -10,7 +10,7 @@ from .utils import PathOrStr
 def get_current_repo(path: PathOrStr = '.') -> Repository:
     root = find_repo_root(path)
     if root is None:
-        raise RepositoryNotFound(f'{CONFIG} files not found in current folder\'s parents')
+        raise RepositoryNotFound(f"{CONFIG} files not found in current folder's parents")
 
     return Repository(root)
 
@@ -20,7 +20,7 @@ def get_consistent_repo_root(paths: Sequence[PathOrStr]) -> Path:
     if len(roots) > 1:
         raise InconsistentRepositories('The paths are located in different repositories')
     if not roots:
-        raise RepositoryNotFound(f'{CONFIG} files not found among folder\'s parents')
+        raise RepositoryNotFound(f"{CONFIG} files not found among folder's parents")
 
     return roots.pop()
 
